Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Op ¶
type Op struct {
Op string `json:"operatorType" yaml:"operatorType" view:"Operator"`
Details string `json:"details,omitempty" yaml:"details,omitempty" view:"Details,omitempty"`
RowsEst int64 `json:"estimatedRows" yaml:"estimatedRows" view:"Estimated Rows"`
Rows int64 `json:"rows" yaml:"rows" view:"Rows"`
DBHits int64 `json:"dbHits" yaml:"dbHits" view:"DB Hits"`
Memory int64 `json:"memory" yaml:"memory" view:"Memory (Bytes)"`
CacheHits int64 `json:"pageCacheHits" yaml:"pageCacheHits" view:"Cache Hits"`
CacheMisses int64 `json:"pageCacheMisses" yaml:"pageCacheMisses" view:"Cache Misses"`
Order string `json:"order,omitempty" yaml:"order,omitempty" view:"Ordered by,omitempty"`
Children []*Op `json:"children,omitempty" yaml:"children,omitempty" view:"-"`
}
Op is a single operation in an execution plan.
type Stats ¶
type Stats struct {
Plan string `json:"plan" yaml:"plan" view:"Plan"`
Statement StmtType `json:"queryType" yaml:"queryType" view:"Statement"`
Version string `json:"version" yaml:"version" view:"Version"`
Planner string `json:"planner" yaml:"planner" view:"Planner"`
Runtime string `json:"runtime" yaml:"runtime" view:"Runtime"`
Time int64 `json:"time" yaml:"time" view:"Time"`
DBHits int64 `json:"dbHits" yaml:"dbHits" view:"DB Hits"`
Rows int64 `json:"rows" yaml:"rows" view:"Rows"`
Memory int64 `json:"memory" yaml:"memory" view:"Memory (Bytes)"`
}
Stats holds the statics of an execution plan.
type StmtType ¶
type StmtType neo4j.StatementType
StmtType is an alias for StatementType. It is used to allow custom string representation and marshalling.
func (StmtType) MarshalJSON ¶
MarshalJSON serializes the statement type as JSON value.
func (StmtType) MarshalYAML ¶
MarshalYAML serializes the statement type as YAML value.
Click to show internal directories.
Click to hide internal directories.